==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/VMwareCbtDiskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMwareCbt disk input.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM Id.
 * @property diskId The disk Id.
 * @property diskType The disk type.
 * @property isOSDisk A value indicating whether the disk is the OS disk.
 * @property logStorageAccountId The log storage account ARM Id.
 * @property logStorageAccountSasSecretName The key vault secret name of the log storage account.
 */
public data class VMwareCbtDiskInputArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>,
    public val diskType: Output<Either<String, DiskAccountType>>? = null,
    public val isOSDisk: Output<String>,
    public val logStorageAccountId: Output<String>,
    public val logStorageAccountSasSecretName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .isOSDisk(isOSDisk.applyValue({ args0 -> args0 }))
            .logStorageAccountId(logStorageAccountId.applyValue({ args0 -> args0 }))
            .logStorageAccountSasSecretName(
                logStorageAccountSasSecretName.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [VMwareCbtDiskInputArgs].
 */
@PulumiTagMarker
public class VMwareCbtDiskInputArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var isOSDisk: Output<String>? = null

    private var logStorageAccountId: Output<String>? = null

    private var logStorageAccountSasSecretName: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("khkivguqtfowslbh")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("ixreoxmhbegwfsuv")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The disk type.
     */
    @JvmName("slsjxwaxoedrpoyk")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value A value indicating whether the disk is the OS disk.
     */
    @JvmName("dtgkblytbuynixbg")
    public suspend fun isOSDisk(`value`: Output<String>) {
        this.isOSDisk = value
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("yxabjobsaxahpcyf")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The key vault secret name of the log storage account.
     */
    @JvmName("lctbwmdaqmmbjfhg")
    public suspend fun logStorageAccountSasSecretName(`value`: Output<String>) {
        this.logStorageAccountSasSecretName = value
    }

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("okbqpgfclalkasxo")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("qmcjumdxxdsnishw")
    public suspend fun diskId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("usyjyadgcsuvbulb")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("agolnfjsbchcrqes")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("licwcvdqisvsibcx")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value A value indicating whether the disk is the OS disk.
     */
    @JvmName("rhlegwuhdlhhmbld")
    public suspend fun isOSDisk(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isOSDisk = mapped
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("nemgoyvjvvwdgfmv")
    public suspend fun logStorageAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    /**
     * @param value The key vault secret name of the log storage account.
     */
    @JvmName("hmbdpxvnbqwewycb")
    public suspend fun logStorageAccountSasSecretName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountSasSecretName = mapped
    }

    internal fun build(): VMwareCbtDiskInputArgs = VMwareCbtDiskInputArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskId = diskId ?: throw PulumiNullFieldException("diskId"),
        diskType = diskType,
        isOSDisk = isOSDisk ?: throw PulumiNullFieldException("isOSDisk"),
        logStorageAccountId = logStorageAccountId ?: throw PulumiNullFieldException("logStorageAccountId"),
        logStorageAccountSasSecretName = logStorageAccountSasSecretName ?: throw
            PulumiNullFieldException("logStorageAccountSasSecretName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/VMwareCbtDiskInputArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.DiskAccountType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * VMwareCbt disk input.
 * @property diskEncryptionSetId The DiskEncryptionSet ARM Id.
 * @property diskId The disk Id.
 * @property diskType The disk type.
 * @property isOSDisk A value indicating whether the disk is the OS disk.
 * @property logStorageAccountId The log storage account ARM Id.
 * @property logStorageAccountSasSecretName The key vault secret name of the log storage account.
 */
public data class VMwareCbtDiskInputArgs(
    public val diskEncryptionSetId: Output<String>? = null,
    public val diskId: Output<String>,
    public val diskType: Output<Either<String, DiskAccountType>>? = null,
    public val isOSDisk: Output<String>,
    public val logStorageAccountId: Output<String>,
    public val logStorageAccountSasSecretName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs =
        com.pulumi.azurenative.recoveryservices.inputs.VMwareCbtDiskInputArgs.builder()
            .diskEncryptionSetId(diskEncryptionSetId?.applyValue({ args0 -> args0 }))
            .diskId(diskId.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .isOSDisk(isOSDisk.applyValue({ args0 -> args0 }))
            .logStorageAccountId(logStorageAccountId.applyValue({ args0 -> args0 }))
            .logStorageAccountSasSecretName(
                logStorageAccountSasSecretName.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [VMwareCbtDiskInputArgs].
 */
@PulumiTagMarker
public class VMwareCbtDiskInputArgsBuilder internal constructor() {
    private var diskEncryptionSetId: Output<String>? = null

    private var diskId: Output<String>? = null

    private var diskType: Output<Either<String, DiskAccountType>>? = null

    private var isOSDisk: Output<String>? = null

    private var logStorageAccountId: Output<String>? = null

    private var logStorageAccountSasSecretName: Output<String>? = null

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("qwmrgtebhhxvjyqn")
    public suspend fun diskEncryptionSetId(`value`: Output<String>) {
        this.diskEncryptionSetId = value
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("wspcqhjbyemtblkm")
    public suspend fun diskId(`value`: Output<String>) {
        this.diskId = value
    }

    /**
     * @param value The disk type.
     */
    @JvmName("uxpceyfflfjmfddm")
    public suspend fun diskType(`value`: Output<Either<String, DiskAccountType>>) {
        this.diskType = value
    }

    /**
     * @param value A value indicating whether the disk is the OS disk.
     */
    @JvmName("quvkuxvmqoxwrkgl")
    public suspend fun isOSDisk(`value`: Output<String>) {
        this.isOSDisk = value
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("camtygtkvcyphxqh")
    public suspend fun logStorageAccountId(`value`: Output<String>) {
        this.logStorageAccountId = value
    }

    /**
     * @param value The key vault secret name of the log storage account.
     */
    @JvmName("awwbeqhsfiarirwv")
    public suspend fun logStorageAccountSasSecretName(`value`: Output<String>) {
        this.logStorageAccountSasSecretName = value
    }

    /**
     * @param value The DiskEncryptionSet ARM Id.
     */
    @JvmName("gspdkykpcelpnkqp")
    public suspend fun diskEncryptionSetId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskEncryptionSetId = mapped
    }

    /**
     * @param value The disk Id.
     */
    @JvmName("wgjqfoufikhgoyhc")
    public suspend fun diskId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskId = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("bkwvthrxulnfqcpo")
    public suspend fun diskType(`value`: Either<String, DiskAccountType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("jmfxudjmvwurjqph")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value The disk type.
     */
    @JvmName("qdivomdeftmhjfpo")
    public fun diskType(`value`: DiskAccountType) {
        val toBeMapped = Either.ofRight<String, DiskAccountType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value A value indicating whether the disk is the OS disk.
     */
    @JvmName("yjpjsjnhkhrphnxa")
    public suspend fun isOSDisk(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isOSDisk = mapped
    }

    /**
     * @param value The log storage account ARM Id.
     */
    @JvmName("xpkylmhrvdvhtbom")
    public suspend fun logStorageAccountId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountId = mapped
    }

    /**
     * @param value The key vault secret name of the log storage account.
     */
    @JvmName("lheosihffwpgxvmc")
    public suspend fun logStorageAccountSasSecretName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.logStorageAccountSasSecretName = mapped
    }

    internal fun build(): VMwareCbtDiskInputArgs = VMwareCbtDiskInputArgs(
        diskEncryptionSetId = diskEncryptionSetId,
        diskId = diskId ?: throw PulumiNullFieldException("diskId"),
        diskType = diskType,
        isOSDisk = isOSDisk ?: throw PulumiNullFieldException("isOSDisk"),
        logStorageAccountId = logStorageAccountId ?: throw PulumiNullFieldException("logStorageAccountId"),
        logStorageAccountSasSecretName = logStorageAccountSasSecretName ?: throw
            PulumiNullFieldException("logStorageAccountSasSecretName"),
    )
}
